###########################################################################
#
#   Copyright (c) 2000 Morten W. Petersen <morten@esol.no>
#	Copyright (c) 2000 Thingamy Ltd.
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, 
#    MA 02111-1307 USA
#
#
###########################################################################

# $Author: morten $
# $Revision: 1.2 $


__doc__ = 'Documentation string.'
__version__ = '0.1.0'

from Globals import HTMLFile
from Globals import Persistent
from Globals import MessageDialog
from Globals import default__class_init__
import Acquisition
import AccessControl.Role
import OFS.Folder
import base_item
import address_book_group


def manage_add_address_book_group_container(self, id='contact_groups',
						title='Address book groups', RESPONSE=None):
	"""Add an instance of the AddressBookContact class."""

	self._setObject(id, address_book_group_container(id, title))

	if RESPONSE is not None:

		RESPONSE.redirect(self.relative_url() + '/' + id)


class address_book_group_container(
	OFS.Folder.Folder,
	Persistent,
	Acquisition.Implicit,
	AccessControl.Role.RoleManager,
	base_item.base_item
	):
	"""Facility for storing contact groups."""

	meta_type = 'AddressBookGroupContainer'
	icon = 'misc_/AddressBook/Folder_icon.gif'

	use_local_navigation = 1

	_properties = (
		{'id':'title', type:'string'},
	)

	meta_types = (
		{'name':'AddressBookGroup', 'action':'manage_add_address_book_group_form'},
	)

	manage_add_address_book_group_form = address_book_group.manage_add_address_book_group_form
	manage_add_address_book_group = address_book_group.manage_add_address_book_group

	__ac_permissions__ = (
		('View management screens',
			('manage_tabs', 'manage_main')
		),
		('Change Permissions',
			('manage_access',)
		),
		('View AddressBookGroups',
			(
				'',
			),
			['Manager', 'Owner', 'AddressBook Manager'],
		),
		('Manage AddressBookGroups',
			(
				'manage_delete',
				'manage_add_address_book_group_form',
				'manage_add_address_book_group'
			),
			['Manager', 'Owner', 'AddressBook Manager'],
		)
	)

	index_html = HTMLFile('dtml/address_book_group_container_index', globals())


	def get_groups(self):
		"""Returns a list of groups."""

		return self.objectValues('AddressBookGroup')


	def __init__(self, id, title):
		"""Initialize the class instance."""

		self.id = id
		self.title = title

		self.manage_add_address_book_group(id='-1', name='Business', description='')
		self.manage_add_address_book_group(id='-2', name='Friends', description='')
		self.manage_add_address_book_group(id='-3', name='Colleagues', description='')


default__class_init__(address_book_group_container)
